#
# spec file for package talhelper
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           talhelper
Version:        3.0.8
Release:        1.1
Summary:        Tool to help creating Talos kubernetes cluster
License:        BSD-3-Clause
URL:            https://github.com/budimanjojo/talhelper
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
The main reason of this tool is to help creating Talos cluster in GitOps way.
Inspired by a python script written by @bjw-s.

You can use this tool to generate Talos config file with talhelper genconfig
command. You can also use this tool to generate Talos secrets with talhelper
gensecret command.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/budimanjojo/talhelper/v3/cmd.version=%{version}" \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check
./bin/%{name} --version | grep %{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Wed Oct 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.8:
  * docs: update CLI reference documentation (#675)
  * chore(deps): update dependency siderolabs/talos to v1.8.2
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.8.2
  * chore(schema): update talos-extensions.yaml JSON schema (#674)
  * feat(readme): Thank you @eocx for the sponsor!
  * chore(github-action): update actions/setup-go action to v5.1.0
  * chore(schema): update talos-extensions.yaml JSON schema (#670)
  * chore(container): update bitnami/kubectl docker tag to v1.31.2
  * chore(github-action): update actions/checkout action to v4.2.2
  * chore(schema): update talos-extensions.yaml JSON schema (#668)
  * chore(github-action): update actions/checkout digest to 11bd719
  * chore(schema): update talos-extensions.yaml JSON schema
  * fix(deps): update module github.com/fatih/color to v1.18.0
  * chore(schema): update talos-extensions.yaml JSON schema (#662)
  * fix(flake): Update package to be talhelper not default
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.9.0-alpha.0
  * feat: add talhelper package and docs
  * feat: add easy overlay for flake parts
  * chore(schema): update talos-extensions.yaml JSON schema (#659)
  * docs(refs): re add the `machineDisks` that was accidentally
    deleted
  * chore(schema): update talos-extensions.yaml JSON schema (#657)
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to 2e00578
  * chore(github-action): update renovatebot/github-action action
    to v40.3.4
  * fix(genconfig): skip applying patch that contains empty file
  * Set meta.mainProgram
  * chore(github-action): update renovatebot/github-action action
    to v40.3.3
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.7
  * feat: update Scoop for talhelper version v3.0.7
  * feat: update flake (#646)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.7:
  * fix: change map type from `map[interface{}]interface{}` to
    `map[string]interface{}`
  * feat(deps): update `gopkg.in/yaml` to v3 for substitute package
  * fix(deps)!: Update module gopkg.in/yaml.v2 to v3
  * chore(github-action): update renovatebot/github-action action
    to v40.3.2
  * fix(CI): don't need `flakes-from-devshell` and typo
  * feat(CI): add test nix build workflow
  * docs: update CLI reference documentation (#643)
  * chore(deps): update dependency siderolabs/talos to v1.8.1
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.8.1
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.1
  * chore(schema): update talos-extensions.yaml JSON schema (#642)
  * chore(github-action): update actions/checkout action to v4.2.1
  * chore(github-action): update actions/checkout digest to eef6144
  * fix(deps): update module github.com/getsops/sops/v3 to v3.9.1
  * chore(container): update ghcr.io/getsops/sops docker tag to
    v3.9.1
  * chore(github-action)!: Update cachix/install-nix-action action
    to v30
  * chore(schema): update talos-extensions.yaml JSON schema (#632)
  * chore(github-action): update renovatebot/github-action action
    to v40.3.1
  * fix: Add support for relative paths when called from another
    dir (#619)
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to 16c623a
  * chore(github-action): update renovatebot/github-action action
    to v40.2.11
  * chore(github-action)!: Update cachix/install-nix-action action
    to v29
  * chore(schema): update talos-extensions.yaml JSON schema (#625)
  * chore(github-action): update actions/checkout action to v4.2.0
  * chore(schema): update talos-extensions.yaml JSON schema (#623)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.6
  * feat(cmd): generate shell completion for `--node` flag
  * chore(container): update alpine:3.20.3 docker digest to beefdbd
  * chore(container): update alpine:3.20.3 docker digest to a8f1201
  * feat: update Scoop for talhelper version v3.0.6
  * feat: update flake (#617)
* Wed Sep 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.6:
  * docs: update CLI reference documentation (#616)
  * chore(deps): update dependency siderolabs/talos to v1.8.0
  * chore(container): update ghcr.io/siderolabs/talosctl docker tag
    to v1.8.0
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.0
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to fa6dbb5
  * chore(schema): update talos-extensions.yaml JSON schema (#615)
  * chore(github-action): update workflow/nix-shell-action action
    to v3.4.0
  * chore(schema): update talos-extensions.yaml JSON schema (#610)
  * chore(schema): update talos-extensions.yaml JSON schema (#608)
  * chore(schema): update talos-extensions.yaml JSON schema (#607)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.3.2
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.0-beta.1
  * chore(github-action): update renovatebot/github-action action
    to v40.2.10
  * chore(schema): update talos-extensions.yaml JSON schema (#606)
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to 089dc0f
  * chore(schema): update talos-extensions.yaml JSON schema (#604)
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.3.1
  * chore(schema): update talos-extensions.yaml JSON schema (#600)
  * chore(container): update bitnami/kubectl docker tag to v1.31.1
  * chore(container): update goreleaser/goreleaser docker tag to
    v2.3.0
  * chore(container): update
    mcr.microsoft.com/devcontainers/go:1.23-bookworm docker digest
    to 9fbee73
  * ci: Use goreleaser to build docker images (#589)
  * chore(schema): update talos-extensions.yaml JSON schema (#594)
  * ci: Add dry-run flag to goreleaser (#588)
  * chore(schema): update talos-extensions.yaml JSON schema (#593)
  * chore(container): update golangci/golangci-lint docker tag to
    v1.61.0
  * add a github workflow to make sure devcontainer image builds
  * update devcontainer configuration to custom docker image
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.0-beta.0
  * chore(schema): update talos-extensions.yaml JSON schema
  * feat(CI): use `gh` to auto merge PR
  * chore(goreleaser): migrate to v2
  * chore(github-action)!: Update goreleaser/goreleaser-action
    action to v6
  * chore(github-action): update renovatebot/github-action action
    to v40.2.8
  * address suggested improvements from review
  * add test for some comment stripping corner cases
  * use full yaml parsing to do comment stripping
  * chore(schema): update talos-extensions.yaml JSON schema
  * chore(schema): update talconfig.yaml JSON schema (#582)
  * feat(config): add support for `nodeAnnotations`
  * fix(deps): update module golang.org/x/mod to v0.21.0
  * chore(github-action)!: Update peter-evans/create-pull-request
    action to v7
  * fix(deps): update module github.com/siderolabs/image-factory to
    v0.5.0
  * chore(schema): update talconfig.yaml JSON schema (#574)
  * feat(config): reflect type changes from upstream to fix test
    failing
  * fix(deps): update module
    github.com/siderolabs/talos/pkg/machinery to v1.8.0-alpha.2
  * chore(schema): update talos-extensions.yaml JSON schema (#573)
  * chore(schema): update talos-extensions.yaml JSON schema (#571)
  * chore(schema): update talos-extensions.yaml JSON schema (#570)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.7
  * feat: update go module to 1.23.0 and update flake
  * feat(code): shut up golangci-lint
  * chore(container): update golang docker tag to v1.23.0 (#560)
  * chore(schema): update talos-extensions.yaml JSON schema (#567)
  * chore(schema): update talos-extensions.yaml JSON schema (#566)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.6
  * chore(schema): update talos-extensions.yaml JSON schema (#564)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.5
  * feat: update Scoop for talhelper version v3.0.5
  * feat: update flake (#562)
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.5:
  * docs: update CLI reference documentation (#561)
  * chore(deps): update dependency siderolabs/talos to v1.7.6
  * fix(deps): update module github.com/google/go-containerregistry
    to v0.20.2
  * chore(schema): update talos-extensions.yaml JSON schema (#559)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.5
  * chore(schema): update talos-extensions.yaml JSON schema (#556)
  * fix(deps): update module golang.org/x/mod to v0.20.0
  * chore(schema): update talos-extensions.yaml JSON schema (#553)
  * chore(schema): update talos-extensions.yaml JSON schema (#552)
  * chore(schema): update talos-extensions.yaml JSON schema (#551)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.4
  * feat(decrypt): add something to make `sops` error message
    friendlier
  * chore(schema): update talos-extensions.yaml JSON schema (#547)
  * chore(github-action): update renovatebot/github-action action
    to v40.2.3
  * fix(deps): update module github.com/google/go-containerregistry
    to v0.20.1
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to
    v3.0.4
  * feat: update Scoop for talhelper version v3.0.4
  * feat: update flake (#540)
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 3.0.4:
  * chore(schema): update talconfig.yaml JSON schema (#539)
  * feat(config): add `noSchematicValidate` to skip schematic validation
  * feat(validate): don't validate on selfhosted image factory
  * chore(github-action)!: Update docker/build-push-action action to v6 (#511)
  * fix: Dockerfile base image and Docker Workflow (#536)
  * fix(deps): update module github.com/budimanjojo/talhelper/v3 to v3.0.3
  * feat: update Scoop for talhelper version v3.0.3
  * feat: update flake (#533)
  * chore: bump flake to upstream go 1.22.5
  * feat(validate): give information about docs on config file not found
* Mon Jul 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package talhelper: tool to help creating Talos kubernetes
  cluster
